:
# NAME:
#	instsvc - install an inetd service
#
# SYNOPSIS:
#	instsvc "svc" "port" "proto" ["user" "server" ["args"]]
#
# DESCRIPTION:
#	Make sure that "svc" appears in "DESTDIR"/etc/services.
#	If "server" is specified and "DESTDIR"/"server" exists, then
#	we also add an appropriate entry to "DESTDIR"/etc/inetd.conf.
#
#	If "proto" is 'tcp' we assume 'stream tcp nowait'.
#	If "proto" is 'udp' we assume 'dgram udp wait'.
#	Anything else and we bail-out.
#
#	The default for "args" is the basename of "server".
#	If "args" is set, it must include the name that the server
#	will run as.
#
#	Examples:
#.nf
#
#		instsvc sshell 614 tcp root /usr/local/libexec/netacl sshell
#		instsvc sshell 614 tcp root /usr/local/libexec/SSLrshd SSLrshd
#
#.fi
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#
#

# RCSid:
#	$Id: instsvc.sh,v 1.8 2008/11/01 16:20:23 sjg Exp $
#
#	@(#) Copyright (c) 1996 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

SERVICES=${SERVICES:-$DESTDIR/etc/services}

instSvc() {
        case "$1" in
	*/inetd*) _inetd_conf=$1; shift;;
	*) _inetd_conf=;;
	esac
        svc=$1
        port=$2
        proto=$3
        user=$4
        server=$5
        alias=

        if [ $# -gt 5 ]; then
                shift 5
                args="$*"
	fi


        case "$port" in
	*,*)
                set -- `IFS=,; echo $port`
                port=$1
                alias=$2
                ;;
	esac
        case "$proto" in
	tcp)	type=stream; nw=nowait;;
	udp)	type=dgram; nw=wait;;
	*)	return 1;;
	esac
        ok=`grep "^$svc[ 	].*$proto" $SERVICES`
        case "$ok" in
	"")	echo "$svc	$port/$proto	$alias" >> $SERVICES;;
	*$port*) ;;		# ok
	*)	echo $SERVICES | sedem.sh "/^$svc[ 	]/s,^.*,$svc	$port/$proto	$alias,";;
	esac

        [ "$server" ] || return 0
        [ -f $DESTDIR/$server ] || return 1

	#
	# if INETD_CONF is set to inetd-*.conf then we will use
	# inetd-x.conf where x is the first letter of svc
	# 
	x=`expr $svc : '^\(.\).*' | tr 'A-Z' 'a-z'`
	for icf in $_inetd_conf $INETD_CONF $DESTDIR/etc/inetd.conf
	do
		[ -s $icf ] || continue
		case $icf in
		*/inetd.conf|*/inetd-$x*.conf)
			;;
		*)	continue;;
		esac
		ok=`grep "^$svc[ 	].*$proto" $DESTDIR/etc/inetd*.conf`
		case "$ok" in
		"")	echo "$svc $type $proto $nw $user $server ${args:-`basename $server`}" >> $icf; break;;
		esac
	done
}

case $0 in
*instsvc*) instSvc $*; exit $?;;
esac
	
