:
# NAME:
#	mkhosts.sh - make a hosts file from the DNS
#
# SYNOPSIS:
#	mkhosts.sh
#
# DESCRIPTION:
#	This script looks for an rc file .mkhostsrc in the current
#	directory or in "CONFIGS/SITE".  This file should contain
#	assignments for the DNS DOMAIN to list, and if need be a
#	SERVER to list it from and a WANT_RE (for egrep(1)) to trim
#	the result. For example:
#.nf
#
#		DOMAIN=crufty.net
#		SERVER=``server zen''
#		WANT_RE='(zen|rex)'
#.fi
#
# AUTHOR:
#	Simon J. Gerraty <sjg@crufty.net>
#
#	

# RCSid:
#	$Id: mkhosts.sh,v 1.2 2001/08/30 09:55:52 sjg Exp $
#
#	@(#) Copyright (c) 1995 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

Myname=`basename $0 .sh`
Mydir=`dirname $0`
case $Mydir in
/*) ;;
*) Mydir=`cd $Mydir; pwd`;;
esac

CONFIGS=${CONFIGS:-`cd $Mydir/..; pwd`}

rc=.${Myname}rc
for d in . $CONFIGS/${SITE:-local} $Mydir
do
        test -s $d/$rc && { . $d/$rc; break; }
done

[ "$DOMAIN" ] || exit 1

sorthosts() {
        grep -v '.-' $1 > $1.$$
        grep '.-' $1 >> $1.$$
        mv $1.$$ $1
}

cat <<! | nslookup >/dev/null 2>&1
$SERVER
ls -d $DOMAIN > /tmp/db.$$
!
# makesure that foo-le0 comes after foo.
sorthosts /tmp/db.$$

cat <<! > hosts.new
#
# HOSTS generated by $Myname `date`
#
127.0.0.1	localhost loghost

!

$CONFIGS/usr/local/etc/dns2hosts.pl /tmp/db.$$ |
egrep "${WANT_RE:-^[1-9]}" >> hosts.new
# this ensures that host-f is listed after host.
sorthosts hosts.new

if [ -s hosts.new ]; then
        [ -s hosts ] && mv hosts hosts.bak
        mv hosts.new hosts
fi
rm -f /tmp/db.$$ 

