:
# RCSid:
#	$Id: source.sh,v 1.16 2022/10/05 19:24:56 sjg Exp $
#
#	@(#) Copyright (c) 1994-2020 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

# this one can cause some shell's to segfault if loaded recursively
# so always use
# $_SOURCE_SH . source.sh
_SOURCE_SH=:

# set isPOSIX_SHELL={true,false}
# so we can use 'if $isPOSIX_SHELL; then'
if (echo ${PATH%:*}) > /dev/null 2>&1; then
    isPOSIX_SHELL=true
    # you need to eval $local var
    local=local
    # reduce the cost of these
    basename() {
        local b=${1%$2}
        echo ${b##*/}
    }
    dirname() {
        case "$1" in
        *?/*) echo ${1%/*};;
        /*) echo /;;
        *) echo .;;
        esac
    }
else
    isPOSIX_SHELL=false
    local=:
    false() {
        return 1
    }
fi

# these are from rc.sh, but others can use them too.
Which() {
    eval $local d t
    
    case "$1" in
    -*) t=$1; shift;;
    *) t=-x;;
    esac
    case "$1" in
    /*) test $t $1 && echo $1;;
    *)
        for d in `IFS=:; echo ${2:-$PATH}`
        do
            test $t $d/$1 && { echo $d/$1; break; }
        done
        ;;
    esac
}

# requires 'local' for source_file etc to have correct values when
# used recursively.
# --once avoids repeats
# --one  stops after first one we find
sb_included=
source_rc() {
    eval $local f source_dir source_file _0 _1

    _0=: _1=:
    while :
    do
        case "$1" in
        --once) _0=; shift;;
        --one) _1=; shift;;
        *) break;;
        esac
    done
    for f in "$@"
    do
        [ -s $f ] || continue
        case $f in
        */*) source_dir=`dirname $f` source_file=`basename $f`;;
        *) source_dir=. source_file=$f;;
        esac
        source_dir=`'cd' "$source_dir" && 'pwd'`
        : is $_0$source_dir/$source_file in ,$sb_included,
        case ",$sb_included," in
        *,$_0$source_dir/$source_file,*) continue;;
        esac
        sb_included=$sb_included,$source_dir/$source_file
        . $f
        $_1 return $?
    done
}

# it is dangerous to override this while in use
case "`type _source 2>&1`" in
*found*)
# handy for finding include files
_source() {
    eval $local d r x f
    f=$1; shift
    case $f in
    :|break) x=$f; f=$1; shift;;
    *) x=break;;
    esac
    for d in "" `IFS=:; echo ${*:-$PATH}`
    do
        test -s $d/$f || continue
	source_rc $d/$f
	$x
    done
}
;;
esac

source_all() { _source : "$@"; }
source_first() { _source "$@"; }
case "`type source 2>&1`" in
*builtin*) ;;
*) source() { _source "$@"; };;
esac


case ./$0 in
*/source*)
    case "$1" in
    --*) source_rc "$@";;
    *) _source "$@";;
    esac
    ;;
*/[wW]hich*) Which "$@";;
esac
